@@ -24,7 +24,7 @@ __all__ = ['AppGeolocIP']
 
 class AppGeolocIP(ReplApplication):
     APPNAME = 'geolocip'
-    VERSION = '3.5'
+    VERSION = '3.6'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Romain Bignon'
     DESCRIPTION = "Console application allowing to geolocalize IP addresses."
     SHORT_DESCRIPTION = "geolocalize IP addresses"
@@ -37,5 +37,5 @@ class AppGeolocIP(ReplApplication):
 
         for location in self.do('get_location', argv[1]):
             if location.lt and location.lg:
-                location.osmlink = 'http://www.openstreetmap.org/?mlat=%s&mlon=%s#map=13/%s/%s' % (location.lt, location.lg, location.lt, location.lg)
+                location.osmlink = 'https://www.openstreetmap.org/?mlat=%s&mlon=%s#map=13/%s/%s' % (location.lt, location.lg, location.lt, location.lg)
             self.format(location)
