@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright(C) 2016      Vincent A
 #
 # This file is part of woob.
@@ -17,7 +15,20 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with woob. If not, see <http://www.gnu.org/licenses/>.
 
-"""Module to use NSS instead of OpenSSL in urllib3/requests."""
+"""
+Module to use NSS instead of OpenSSL in urllib3/requests.
+
+As it was used by Firefox, it offered the same security level, to be sure woob
+can access to a website the same way than a real browser.
+
+.. deprecated:: 3.4
+   NSS is not maintained by Mozilla anymore, so do not use it anymore.
+
+   If there is an issue to access a website, you can override use the
+   :class:`woob.browser.adapters.LowSecHTTPAdapter` with the
+   :attr:`woob.browser.browsers.Browser.HTTP_ADAPTER_CLASS` attribute to be
+   explicitely more permissive.
+"""
 
 # create db:
 #   mkdir pki
@@ -26,8 +37,6 @@
 # import certificate:
 #   find -L /etc/ssl/certs -name "*.pem" | while read f; do certutil -A -d pki -i $f -n $f -t TCu,Cu,Tu; done
 
-from __future__ import absolute_import
-
 from functools import wraps
 from io import RawIOBase, BufferedRWPair
 import hashlib
@@ -38,6 +47,7 @@ import ssl as basessl
 import subprocess
 from tempfile import NamedTemporaryFile
 from threading import Lock
+import warnings
 
 try:
     import nss.ssl
@@ -50,6 +60,9 @@ import requests  # for AIA
 from woob.tools.log import getLogger
 
 
+warnings.warn('Use of NSS is deprecated, it will be removed in woob 4.0', DeprecationWarning, stacklevel=2)
+
+
 __all__ = ['init_nss', 'inject_in_urllib3', 'certificate_db_filename']
 
 
@@ -183,7 +196,7 @@ class NSSFile(RawIOBase):
     writable = readable
 
 
-class Wrapper(object):
+class Wrapper:
     def __init__(self, obj):
         self.__obj = obj
         self.__timeout = nss.io.PR_INTERVAL_NO_TIMEOUT
@@ -278,7 +291,7 @@ def auth_cert_aia_only(sock, check_sig, is_server):
         parent_der = AIA_CACHE.get(parent_url)
 
     if parent_der is None:
-        parent_der = requests.get(parent_url).content
+        parent_der = requests.get(parent_url, timeout=30).content
         with AIA_LOCK:
             AIA_CACHE[parent_url] = parent_der
 
